@@ -25,6 +25,10 @@ import logging
 logger = logging.getLogger('nl')
 here = path.join(path.dirname(__file__))
 log_file = here + '/clips/log.clp'
+if not path.isfile(log_file):
+    f = open(log_file, 'w')
+    f.write('log file for nl\n\n')
+    f.close()
 hdlr = logging.FileHandler(log_file)
 formatter = logging.Formatter('%(message)s')
 # formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
